/* Tabela COMPCARD: Pratos do Cardpio */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela COMPCARD */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela COMPCARD,
             utilizando a tabela Geral de Logs de Operaes */

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'LOG_PLA_COMPCARD'  and
            type = 'TR'               and
            u.uid = o.uid             and
            u.name = USER)
   DROP TRIGGER LOG_PLA_COMPCARD
GO

CREATE TRIGGER LOG_PLA_COMPCARD
ON COMPCARD
AFTER DELETE, INSERT, UPDATE
AS
BEGIN
   DECLARE @V_USUARIO         VARCHAR(40);
   DECLARE @V_TIPO            VARCHAR(1);
   DECLARE @V_ITPESQ          VARCHAR(40);
   DECLARE @V_DESC            VARCHAR(500);
   DECLARE @V_DTOPER          DATETIME;

   DECLARE  @V_DSREMOTEADDR     VARCHAR(15);
   DECLARE  @V_DSREMOTEHOST     VARCHAR(15);
   DECLARE  @V_DSSERVERRDM      VARCHAR(20);
   DECLARE  @V_DSSERVMETHOD     VARCHAR(30);
   DECLARE  @V_DSREMOTEOPER     VARCHAR(12);


/* Variveis do cursor */
   DECLARE @V_IDCOMANDO          VARCHAR(1);
   DECLARE @V_NEW_CDFILIAL       VARCHAR(4);
   DECLARE @V_NEW_NRCARDAPIO     VARCHAR(10);
   DECLARE @V_NEW_NRSEQPRATCAR   SMALLINT;
   DECLARE @V_NEW_CDFILAUXPRAT   VARCHAR(4);
   DECLARE @V_NEW_CDPRATO        VARCHAR(10);
   DECLARE @V_NEW_VRPECONSCARD   FLOAT;
   DECLARE @V_NEW_CDTIPOPRAT     VARCHAR(4);
   DECLARE @V_NEW_QTSOBRLIMPPR   FLOAT;
   DECLARE @V_NEW_QTCOMEFETPRA   FLOAT;
   DECLARE @V_NEW_QTPRODUZPRAT   FLOAT;
   DECLARE @V_NEW_NRORDPRATCAR   NUMERIC;

   DECLARE @V_OLD_CDFILIAL       VARCHAR(4);
   DECLARE @V_OLD_NRCARDAPIO     VARCHAR(10);
   DECLARE @V_OLD_NRSEQPRATCAR   SMALLINT;
   DECLARE @V_OLD_CDFILAUXPRAT   VARCHAR(4);
   DECLARE @V_OLD_CDPRATO        VARCHAR(10);
   DECLARE @V_OLD_VRPECONSCARD   FLOAT;
   DECLARE @V_OLD_CDTIPOPRAT     VARCHAR(4);
   DECLARE @V_OLD_QTSOBRLIMPPR   FLOAT;
   DECLARE @V_OLD_QTCOMEFETPRA   FLOAT;
   DECLARE @V_OLD_QTPRODUZPRAT   FLOAT;
   DECLARE @V_OLD_NRORDPRATCAR   NUMERIC;


   SET  @V_TIPO = '0';
   SET  @V_DESC = '';
  
   EXEC NMUSUARIO @V_USUARIO;
   EXEC WEBTUNNING @V_DSREMOTEADDR,
                   @V_DSREMOTEHOST,
                   @V_DSSERVERRDM,
                   @V_DSSERVMETHOD,
                   @V_DSREMOTEOPER;
  
   SET @V_USUARIO = ISNULL(@V_USUARIO, '');


   DECLARE C_DADOS CURSOR FOR
      SELECT
         'D' IDCOMANDO,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          CDFILIAL,
          NRCARDAPIO,
          NRSEQPRATCAR,
          CDFILAUXPRAT,
          CDPRATO,
          VRPECONSCARD,
          CDTIPOPRAT,
          QTSOBRLIMPPR,
          QTCOMEFETPRA,
          QTPRODUZPRAT,
          NRORDPRATCAR

      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)

      UNION ALL

      SELECT
         'U' IDCOMANDO,
          INSERTED.CDFILIAL,
          INSERTED.NRCARDAPIO,
          INSERTED.NRSEQPRATCAR,
          INSERTED.CDFILAUXPRAT,
          INSERTED.CDPRATO,
          INSERTED.VRPECONSCARD,
          INSERTED.CDTIPOPRAT,
          INSERTED.QTSOBRLIMPPR,
          INSERTED.QTCOMEFETPRA,
          INSERTED.QTPRODUZPRAT,
          INSERTED.NRORDPRATCAR,

          DELETED.CDFILIAL,
          DELETED.NRCARDAPIO,
          DELETED.NRSEQPRATCAR,
          DELETED.CDFILAUXPRAT,
          DELETED.CDPRATO,
          DELETED.VRPECONSCARD,
          DELETED.CDTIPOPRAT,
          DELETED.QTSOBRLIMPPR,
          DELETED.QTCOMEFETPRA,
          DELETED.QTPRODUZPRAT,
          DELETED.NRORDPRATCAR

      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDFILIAL      =  DELETED.CDFILIAL    AND
         INSERTED.NRCARDAPIO    =  DELETED.NRCARDAPIO  AND
         INSERTED.CDPRATO       =  DELETED.CDPRATO     AND
         INSERTED.NRSEQPRATCAR  =  DELETED.NRSEQPRATCAR

      UNION ALL

      SELECT
         'I' IDCOMANDO,
          CDFILIAL,
          NRCARDAPIO,
          NRSEQPRATCAR,
          CDFILAUXPRAT,
          CDPRATO,
          VRPECONSCARD,
          CDTIPOPRAT,
          QTSOBRLIMPPR,
          QTCOMEFETPRA,
          QTPRODUZPRAT,
          NRORDPRATCAR,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL

      FROM
         INSERTED
      WHERE
         0 = (SELECT COUNT(*) FROM DELETED);

   OPEN C_DADOS;
   FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_NEW_CDFILIAL,
                                @V_NEW_NRCARDAPIO,
                                @V_NEW_NRSEQPRATCAR,
                                @V_NEW_CDFILAUXPRAT,
                                @V_NEW_CDPRATO,
                                @V_NEW_VRPECONSCARD,
                                @V_NEW_CDTIPOPRAT,
                                @V_NEW_QTSOBRLIMPPR,
                                @V_NEW_QTCOMEFETPRA,
                                @V_NEW_QTPRODUZPRAT,
                                @V_NEW_NRORDPRATCAR,
                                @V_OLD_CDFILIAL,
                                @V_OLD_NRCARDAPIO,
                                @V_OLD_NRSEQPRATCAR,
                                @V_OLD_CDFILAUXPRAT,
                                @V_OLD_CDPRATO,
                                @V_OLD_VRPECONSCARD,
                                @V_OLD_CDTIPOPRAT,
                                @V_OLD_QTSOBRLIMPPR,
                                @V_OLD_QTCOMEFETPRA,
                                @V_OLD_QTPRODUZPRAT,
                                @V_OLD_NRORDPRATCAR

   WHILE (@@FETCH_STATUS = 0) BEGIN

      IF @V_IDCOMANDO = 'D' /* Deleting */ BEGIN
         IF (ISNULL(@V_OLD_CDFILIAL, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + 'Fili=' + @V_OLD_CDFILIAL;
         END;

         IF (ISNULL(@V_OLD_NRCARDAPIO, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' Card=' + @V_OLD_NRCARDAPIO;
         END;

         IF (ISNULL(@V_OLD_CDTIPOPRAT, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' TipoPrat=' + @V_OLD_CDTIPOPRAT;
         END;

         IF (ISNULL(@V_OLD_CDPRATO, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' Prato=' + @V_OLD_CDPRATO;
         END;

         IF (ISNULL(@V_OLD_CDFILAUXPRAT, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' Arv=' + @V_OLD_CDFILAUXPRAT;
         END;

         IF (ISNULL(@V_OLD_QTCOMEFETPRA, 0) <> 0) BEGIN
            SET @V_DESC = @V_DESC + ' EfetPrat=' + CONVERT(VARCHAR, @V_OLD_QTCOMEFETPRA);
         END;

         IF (ISNULL(@V_OLD_NRSEQPRATCAR, 0) <> 0) BEGIN
            SET @V_DESC = @V_DESC + ' Sequ=' + CONVERT(VARCHAR, @V_OLD_NRSEQPRATCAR);
         END;

         IF (ISNULL(@V_OLD_VRPECONSCARD, 0) <> 0) BEGIN
            SET @V_DESC = @V_DESC + ' PercentualCons=' + CONVERT(VARCHAR, @V_OLD_VRPECONSCARD);
         END;

         IF (ISNULL(@V_OLD_QTSOBRLIMPPR, 0) <> 0) BEGIN
            SET @V_DESC = @V_DESC + ' SobraLimpa=' + CONVERT(VARCHAR, @V_OLD_QTSOBRLIMPPR);
         END;

         IF (ISNULL(@V_OLD_QTPRODUZPRAT, 0) <> 0) BEGIN
            SET @V_DESC = @V_DESC + ' QtdeVend=' + CONVERT(VARCHAR, @V_OLD_QTPRODUZPRAT);
         END;

         IF (ISNULL(@V_OLD_NRORDPRATCAR, 0) <> 0) BEGIN
            SET @V_DESC = @V_DESC + ' OrdemVisual=' + CONVERT(VARCHAR, @V_OLD_NRORDPRATCAR);
         END;

         SET @V_TIPO = '3';
         SET @V_ITPESQ = @V_OLD_CDFILIAL   +
                         @V_OLD_NRCARDAPIO +
                         @V_OLD_CDPRATO    +
                         CONVERT(VARCHAR, @V_OLD_NRSEQPRATCAR);

         
      END 
      ELSE BEGIN
         IF @V_IDCOMANDO = 'U' /* Updating */ BEGIN
            IF (@V_OLD_CDFILIAL     <> @V_NEW_CDFILIAL    ) OR
               (@V_OLD_NRCARDAPIO   <> @V_NEW_NRCARDAPIO  ) OR
               (@V_OLD_NRSEQPRATCAR <> @V_NEW_NRSEQPRATCAR) OR
               (@V_OLD_CDFILAUXPRAT <> @V_NEW_CDFILAUXPRAT) OR
               (@V_OLD_CDPRATO      <> @V_NEW_CDPRATO     ) OR
               (@V_OLD_VRPECONSCARD <> @V_NEW_VRPECONSCARD) OR
               (@V_OLD_CDTIPOPRAT   <> @V_NEW_CDTIPOPRAT  ) OR
               (ISNULL(@V_OLD_QTSOBRLIMPPR, 0) <> ISNULL(@V_NEW_QTSOBRLIMPPR, 0)) OR
               (ISNULL(@V_OLD_QTCOMEFETPRA, 0) <> ISNULL(@V_NEW_QTCOMEFETPRA, 0)) OR
               (ISNULL(@V_OLD_QTPRODUZPRAT, 0) <> ISNULL(@V_NEW_QTPRODUZPRAT, 0)) OR
               (ISNULL(@V_OLD_NRORDPRATCAR, 0) <> ISNULL(@V_NEW_NRORDPRATCAR, 0)) BEGIN

               SET @V_TIPO  = '2';
               SET @V_ITPESQ = @V_OLD_CDFILIAL   +
                               @V_OLD_NRCARDAPIO +
                               @V_OLD_CDPRATO    +
                               CONVERT(VARCHAR, @V_OLD_NRSEQPRATCAR);

            END;
         END
         ELSE BEGIN
            SET @V_TIPO   = '1';
            SET @V_ITPESQ = @V_NEW_CDFILIAL   +
                            @V_NEW_NRCARDAPIO +
                            @V_NEW_CDPRATO    +
                            CONVERT(VARCHAR, @V_NEW_NRSEQPRATCAR);
         END;

         IF (ISNULL(@V_NEW_CDFILIAL, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + 'Fili=' + @V_NEW_CDFILIAL;
         END;

         IF (ISNULL(@V_NEW_NRCARDAPIO, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' Card=' + @V_NEW_NRCARDAPIO;
         END;

         IF (ISNULL(@V_NEW_CDTIPOPRAT, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' TipoPrat=' + @V_NEW_CDTIPOPRAT;
         END;

         IF (ISNULL(@V_NEW_CDPRATO, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' Prato=' + @V_NEW_CDPRATO;
         END;

         IF (ISNULL(@V_NEW_CDFILAUXPRAT, '!') <> '!') BEGIN
            SET @V_DESC = @V_DESC + ' Arv=' + @V_NEW_CDFILAUXPRAT;
         END;

         IF (ISNULL(@V_NEW_QTCOMEFETPRA, 0) <> ISNULL(@V_OLD_QTCOMEFETPRA, 0)) BEGIN
            IF @V_IDCOMANDO = 'U' BEGIN
               SET @V_DESC = @V_DESC + ' EfetPrat=' + CONVERT(VARCHAR, @V_OLD_QTCOMEFETPRA) + '|' + CONVERT(VARCHAR, @V_NEW_QTCOMEFETPRA);
            END;
            ELSE BEGIN
               SET @V_DESC = @V_DESC + ' EfetPrat=' + CONVERT(VARCHAR, @V_NEW_QTCOMEFETPRA);
            END;
         END;

         IF (ISNULL(@V_NEW_NRSEQPRATCAR, 0) <> ISNULL(@V_OLD_NRSEQPRATCAR, 0)) BEGIN
            IF @V_IDCOMANDO = 'U' BEGIN
               SET @V_DESC = @V_DESC + ' Sequ=' + CONVERT(VARCHAR, @V_OLD_NRSEQPRATCAR) + '|' + CONVERT(VARCHAR, @V_NEW_NRSEQPRATCAR);
            END;
            ELSE BEGIN
               SET @V_DESC = @V_DESC + ' Sequ=' + CONVERT(VARCHAR, @V_NEW_NRSEQPRATCAR);
            END;
         END;

         IF (ISNULL(@V_NEW_VRPECONSCARD, 0) <> ISNULL(@V_OLD_VRPECONSCARD, 0)) BEGIN
            IF @V_IDCOMANDO = 'U' BEGIN
               SET @V_DESC = @V_DESC + ' PercentualCons=' + CONVERT(VARCHAR, @V_OLD_VRPECONSCARD) + '|' + CONVERT(VARCHAR, @V_NEW_VRPECONSCARD);
            END;
            ELSE BEGIN
               SET @V_DESC = @V_DESC + ' PercentualCons=' + CONVERT(VARCHAR, @V_NEW_VRPECONSCARD);
            END;
         END;

         IF (ISNULL(@V_NEW_QTSOBRLIMPPR, 0) <> ISNULL(@V_OLD_QTSOBRLIMPPR, 0)) BEGIN
            IF @V_IDCOMANDO = 'U' BEGIN
               SET @V_DESC = @V_DESC + ' SobraLimpa=' + CONVERT(VARCHAR, @V_OLD_QTSOBRLIMPPR) + '|' + CONVERT(VARCHAR, @V_NEW_QTSOBRLIMPPR);
            END;
            ELSE BEGIN
               SET @V_DESC = @V_DESC + ' SobraLimpa=' + CONVERT(VARCHAR, @V_NEW_QTSOBRLIMPPR);
            END;
         END;

         IF (ISNULL(@V_NEW_QTPRODUZPRAT, 0) <> ISNULL(@V_OLD_QTPRODUZPRAT, 0)) BEGIN
            IF @V_IDCOMANDO = 'U' BEGIN
               SET @V_DESC = @V_DESC + ' QtdeVend=' + CONVERT(VARCHAR, @V_OLD_QTPRODUZPRAT) + '|' + CONVERT(VARCHAR, @V_NEW_QTPRODUZPRAT);
            END;
            ELSE BEGIN
               SET @V_DESC = @V_DESC + ' QtdeVend=' + CONVERT(VARCHAR, @V_NEW_QTPRODUZPRAT);
            END;
         END;

         IF (ISNULL(@V_NEW_NRORDPRATCAR, 0) <> ISNULL(@V_OLD_NRORDPRATCAR, 0)) BEGIN
            IF @V_IDCOMANDO = 'U' BEGIN
               SET @V_DESC = @V_DESC + ' OrdemVisual=' + CONVERT(VARCHAR, @V_OLD_NRORDPRATCAR) + '|' + CONVERT(VARCHAR, @V_NEW_NRORDPRATCAR);
            END;
            ELSE BEGIN
               SET @V_DESC = @V_DESC + ' OrdemVisual=' + CONVERT(VARCHAR, @V_NEW_NRORDPRATCAR);
            END;
         END;
      END;

      IF @V_TIPO <> '0' BEGIN
         IF NOT @V_DESC IS NULL BEGIN
            SET @V_USUARIO = '  ';
            IF NOT @V_USUARIO IS NULL BEGIN
               SET @V_DTOPER =  GETDATE();
	       SELECT 
                   @V_DSSERVERRDM  = DSSERVERRDM, 
                   @V_DSREMOTEADDR = DSREMOTEADDR, 
                   @V_DSREMOTEHOST = DSREMOTEHOST,
		   @V_DSSERVMETHOD = DSSERVMETHOD, 
                   @V_DSREMOTEOPER = DSREMOTEOPER
	       FROM 
                   SQLWEBTUNNING;
               INSERT INTO LOGOPERA
                  (NMTABELA,   DTOPERACAO, NMRESPOPER, IDTIPOOPER, CDPESQITEM, DSOPERACAO,
                   DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER, CDORESPOPER)
               VALUES
                  ('COMPCARD',  @V_DTOPER, @V_USUARIO, @V_TIPO,  @V_ITPESQ, @V_DESC,
                   @V_DSSERVERRDM, @V_DSREMOTEADDR,  @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER);
            END;  
         END;
      END;


      FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                   @V_NEW_CDFILIAL,
                                   @V_NEW_NRCARDAPIO,
                                   @V_NEW_NRSEQPRATCAR,
                                   @V_NEW_CDFILAUXPRAT,
                                   @V_NEW_CDPRATO,
                                   @V_NEW_VRPECONSCARD,
                                   @V_NEW_CDTIPOPRAT,
                                   @V_NEW_QTSOBRLIMPPR,
                                   @V_NEW_QTCOMEFETPRA,
                                   @V_NEW_QTPRODUZPRAT,
                                   @V_NEW_NRORDPRATCAR,
                                   @V_OLD_CDFILIAL,
                                   @V_OLD_NRCARDAPIO,
                                   @V_OLD_NRSEQPRATCAR,
                                   @V_OLD_CDFILAUXPRAT,
                                   @V_OLD_CDPRATO,
                                   @V_OLD_VRPECONSCARD,
                                   @V_OLD_CDTIPOPRAT,
                                   @V_OLD_QTSOBRLIMPPR,
                                   @V_OLD_QTCOMEFETPRA,
                                   @V_OLD_QTPRODUZPRAT,
                                   @V_OLD_NRORDPRATCAR
   END;
   CLOSE      C_DADOS;
   DEALLOCATE C_DADOS;
END;
GO




-- VERSAO --
EXEC ATUVEROBJ 'LOG_PLA_COMPCARD','5.01.016';
GO

